# streamlit-component-video

A new video with track

## Installation instructions 

```sh
pip install streamlit-component-video
```

## Usage instructions

```python
import streamlit as st

from streamlit_component_video import streamlit_component_video

value = streamlit_component_video()

st.write(value)
